@@ -11,7 +11,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.6.1';
+our $VERSION = '0.1';
 
 =head1 NAME
 
@@ -49,7 +49,7 @@ Mac::iTunes::Library::Playlist - Perl extension for representing a playlist
             'Smart Info' => $smartInfo,
             'Smart Criteria' => $smartCriteria,
             'Playlist Items' => @items,
-        );
+		);
 
   # Add another item to that playlist
   my $item = Mac::iTunes::Library::Item->new( 'Track ID' => 7 );
@@ -119,39 +119,39 @@ a hash:
 =cut
 
 sub new {
-    my $class = shift;
-    my %params = @_;
+	my $class = shift;
+	my %params = @_;
 
-    my $self = {
-        'Name' => undef,
-        'Playlist ID' => undef,
-        'Playlist Persistent ID' => undef,
-        'All Items' => undef,
-        'Smart Info' => undef,
-        'Smart Criteria' => undef,
-        'Playlist Items' => [],
-    };
+	my $self = {
+		'Name' => undef,
+		'Playlist ID' => undef,
+		'Playlist Persistent ID' => undef,
+		'All Items' => undef,
+		'Smart Info' => undef,
+		'Smart Criteria' => undef,
+		'Playlist Items' => [],
+	};
 
-    bless $self, $class;
+	bless $self, $class;
 
-    # Deal with parameters
-    if ( exists( $params{'Name'} ) ) {
-        name( $self, $params{'Name'} );
-    } if ( exists( $params{'Playlist ID'} ) ) {
-        playlistID( $self, $params{'Playlist ID'} );
-    } if ( exists( $params{'Playlist Persistent ID'} ) ) {
-        playlistPersistentID( $self, $params{'Playlist Persistent ID'} );
-    } if ( exists( $params{'All Items'} ) ) {
-        allItems( $self, $params{'All Items'} );
-    } if ( exists( $params{'Smart Info'} ) ) {
-        smartInfo( $self, $params{'Smart Info'} );
-    } if ( exists( $params{'Smart Criteria'} ) ) {
-        smartCriteria( $self, $params{'Smart Criteria'} );
-    } if ( exists( $params{'Playlist Items'} ) ) {
-        addItems( $self, $params{'Playlist Items'} );
-    }
+	# Deal with parameters
+	if ( exists( $params{'Name'} ) ) {
+		name( $self, $params{'Name'} );
+	} if ( exists( $params{'Playlist ID'} ) ) {
+		playlistID( $self, $params{'Playlist ID'} );
+	} if ( exists( $params{'Playlist Persistent ID'} ) ) {
+		playlistPersistentID( $self, $params{'Playlist Persistent ID'} );
+	} if ( exists( $params{'All Items'} ) ) {
+		allItems( $self, $params{'All Items'} );
+	} if ( exists( $params{'Smart Info'} ) ) {
+		smartInfo( $self, $params{'Smart Info'} );
+	} if ( exists( $params{'Smart Criteria'} ) ) {
+		smartCriteria( $self, $params{'Smart Criteria'} );
+	} if ( exists( $params{'Playlist Items'} ) ) {
+		addItems( $self, $params{'Playlist Items'} );
+	}
 
-    return $self;
+	return $self;
 } #new
 
 # Clean up
@@ -170,10 +170,10 @@ sub name {
 
     if (@_) {
         my $name = shift;
-        $self->{'Name'} = $name;
+        $self->{'name'} = $name;
     }
 
-    return $self->{'Name'};
+    return $self->{'name'};
 } #name
 
 =item playlistID( id )
@@ -281,14 +281,13 @@ Add an item to this playlist; duplicates are allowed
 =cut
 
 sub addItem {
-    my $self = shift;
+	my $self = shift;
     my $item = shift;
 
     return carp "Need a Mac::iTunes::Library::Item object."
         unless ($item->isa('Mac::iTunes::Library::Item'));
 
     push @{$self->{'items'}}, $item;
-    # TODO: shouldn't this be referencing a track already in the lib?
 } #addItem
 
 =item addItems( Mac::iTunes::Library::Item )
@@ -298,7 +297,7 @@ Add an array of items to this playlist; duplicates are allowed
 =cut
 
 sub addItems {
-    my $self = shift;
+	my $self = shift;
     my $items = shift;
 
     # Complain if there are any non-item objects
@@ -346,25 +345,11 @@ L<Mac::iTunes::Library>, L<Mac::iTunes::Library::Item>
 
 =head1 AUTHOR
 
-Drew Stephens <drew@dinomite.net>, http://dinomite.net
-
-=head1 CONTRIBUTORS
-
-Mark Grimes <mgrimes@cpan.org>, http://www.peculiarities.com
-
-=head1 SOURCE REPOSITORY
-
-http://mac-itunes.googlecode.com
-
-=head1 SVN INFO
-
-$Revision: 74 $
-$Date: 2009-11-08 17:38:44 -0800 (Sun, 08 Nov 2009) $
-$Author: drewgstephens $
+Drew Stephens, <lt>drewgstephens@gmail.com<gt>, http://dinomite.net
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007-2008 by Drew Stephens
+Copyright (C) 2007 by Drew Stephens
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
